@@ -1,23 +1,30 @@
 (defvar rail-install-list
-  '("rail-user-agent.el"
+  '("rail-common.el"
+    "rail-user-agent.el"
+    ("rail-mule.el" . (and (not (featurep 'xemacs)) (featurep 'mule)))
+    ("rail-xmas.el" . (featurep 'xemacs))
     "rail-table-mule.el"
     "rail-table-meadow.el"
-    "rail-table-xemacs.el"
+    "rail-table-xmas.el"
     "rail-table-utf2000.el"
     "rail-table-flim.el"
     "rail-table-semi.el"
     "rail-pj.el"
+    "rail-vars.el"
     "rail.el"))
 
+;;################
+
 (or (fboundp 'make-directory-internal)
     (defsubst make-directory-internal (dir)
       (call-process "mkdir" nil nil nil dir)))
 
 (defun make-directory-one (dir)
-  (if (and (file-exists-p dir) (not (file-directory-p dir)))
-      (error "Cannot make site-lisp directory: file \"%s\" exists." dir)
-    (or (file-exists-p dir)
-        (make-directory-internal dir))))
+  (or (and (file-exists-p dir)
+	   (not (file-directory-p dir))
+	   (error "Cannot make site-lisp directory: file \"%s\" exists." dir))
+      (file-exists-p dir)
+      (make-directory-internal dir)))
 
 (defun get-bindir ()
   (message
@@ -59,27 +66,44 @@
 
 ;;################
 
+(defun get-filename (file)
+  (or (and (stringp file)
+	   (file-exists-p file)
+	   file)
+      (and (consp file)
+	   (eval (cdr file))
+	   (stringp (car file))
+	   (car file))))
+
 (defun compile-lisp (list)
   (mapcar
-   '(lambda (file)
-      (let ((compiled (concat file "c")))
-        (and (file-newer-than-file-p file compiled)
-             (byte-compile-file file))))
+   '(lambda (cell)
+      (let (file compiled)
+	(and (setq file (get-filename cell))
+	     (setq compiled (concat file "c"))
+	     (file-newer-than-file-p file compiled)
+	     (byte-compile-file file))))
    list))
 
 (defun install-lisp (src dst)
+  (message "Install *.el files...")
   (mapcar
-   '(lambda (file)
-      (message "%s" file)
-      (copy-file file (concat dst file) t t))
+   '(lambda (list)
+      (let ((file (get-filename list)))
+        (and (stringp file)
+             (message "%s -> %s" file dst)
+             (copy-file file (concat dst (file-name-nondirectory file)) t t))))
    rail-install-list)
+  (message "done.")
+  (message "Install *.elc files...")
   (mapcar
    '(lambda (file)
       (cond ((string-match ".*\\.elc$" file)
-             (message "%s" file)
-             (copy-file file (concat dst file) t t)
+             (message "%s -> %s" file dst)
+             (copy-file file (concat dst (file-name-nondirectory file)) t t)
              (delete-file file))))
-   (directory-files src)))
+   (directory-files src))
+  (message "done."))
 
 (defsubst install-current-lisp (dir)
   (install-lisp (expand-file-name "./") dir))
@@ -94,7 +118,8 @@
                  (throw 'found t)))
           features))
        (require 'mime-def))
-  (compile-lisp rail-install-list))
+  (let ((load-path (cons (expand-file-name ".") load-path)))
+    (compile-lisp rail-install-list)))
 
 (defun install-rail ()
   (compile-rail)
